==> gimp-1.3.0.tar.bz2: gimp-1.3.0/app/core/gimpundo.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_UNDO_H__
#define __GIMP_UNDO_H__


#include "gimpviewable.h"


#define GIMP_TYPE_UNDO            (gimp_undo_get_type ())
#define GIMP_UNDO(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_UNDO, GimpUndo))
#define GIMP_UNDO_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_UNDO, GimpUndoClass))
#define GIMP_IS_UNDO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_UNDO))
#define GIMP_IS_UNDO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_UNDO))
#define GIMP_UNDO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_UNDO, GimpUndoClass))


typedef gboolean (* GimpUndoPopFunc)  (GimpUndo *undo, GimpImage *gimage);
typedef void     (* GimpUndoFreeFunc) (GimpUndo *undo);


typedef struct _GimpUndoClass GimpUndoClass;

struct _GimpUndo
{
  GimpViewable      parent_instance;

  gpointer          data;           /* data to implement the undo */
  glong             size;           /* size of undo item          */
  gboolean          dirties_image;  /* TRUE if undo mutates image */

  GimpUndoPopFunc   pop_func;       /* function pointer to undo pop proc  */
  GimpUndoFreeFunc  free_func;      /* function pointer to free undo data */
  
  TempBuf          *preview;
};

struct _GimpUndoClass
{
  GimpViewableClass  parent_class;

  void (* push)  (GimpUndo  *undo,
                  GimpImage *gimage);
  void (* pop)   (GimpUndo  *undo,
                  GimpImage *gimage);
};


GType      gimp_undo_get_type (void);
GimpUndo * gimp_undo_new      (const gchar      *name,
                               gpointer          data,
                               glong             size,
                               gboolean          dirties_image,
                               GimpUndoPopFunc   pop_func,
                               GimpUndoFreeFunc  free_func);
void       gimp_undo_push     (GimpUndo         *undo,
                               GimpImage        *gimage);
void       gimp_undo_pop      (GimpUndo         *undo,
                               GimpImage        *gimage);


#endif /* __GIMP_UNDO_H__ */

==> gimp-1.3.1.tar.bz2: gimp-1.3.1/app/core/gimpundo.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_UNDO_H__
#define __GIMP_UNDO_H__


#include "gimpviewable.h"


#define GIMP_TYPE_UNDO            (gimp_undo_get_type ())
#define GIMP_UNDO(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GIMP_TYPE_UNDO, GimpUndo))
#define GIMP_UNDO_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GIMP_TYPE_UNDO, GimpUndoClass))
#define GIMP_IS_UNDO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GIMP_TYPE_UNDO))
#define GIMP_IS_UNDO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GIMP_TYPE_UNDO))
#define GIMP_UNDO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GIMP_TYPE_UNDO, GimpUndoClass))


typedef gboolean (* GimpUndoPopFunc)  (GimpUndo *undo, GimpImage *gimage);
typedef void     (* GimpUndoFreeFunc) (GimpUndo *undo);


typedef struct _GimpUndoClass GimpUndoClass;

struct _GimpUndo
{
  GimpViewable      parent_instance;

  gpointer          data;           /* data to implement the undo */
  glong             size;           /* size of undo item          */
  gboolean          dirties_image;  /* TRUE if undo mutates image */

  GimpUndoPopFunc   pop_func;       /* function pointer to undo pop proc  */
  GimpUndoFreeFunc  free_func;      /* function pointer to free undo data */
  
  TempBuf          *preview;
};

struct _GimpUndoClass
{
  GimpViewableClass  parent_class;

  void (* push)  (GimpUndo  *undo,
                  GimpImage *gimage);
  void (* pop)   (GimpUndo  *undo,
                  GimpImage *gimage);
};


GType      gimp_undo_get_type (void) G_GNUC_CONST;
GimpUndo * gimp_undo_new      (const gchar      *name,
                               gpointer          data,
                               glong             size,
                               gboolean          dirties_image,
                               GimpUndoPopFunc   pop_func,
                               GimpUndoFreeFunc  free_func);
void       gimp_undo_push     (GimpUndo         *undo,
                               GimpImage        *gimage);
void       gimp_undo_pop      (GimpUndo         *undo,
                               GimpImage        *gimage);


#endif /* __GIMP_UNDO_H__ */
